@@ -2,9 +2,9 @@ import time
 
 import gigapipe
 
-gigapipe.client_secret = "gigapipe_sk_QuoyCCRI-HSiXwOOXaE5ZAGgPY3WqbY65bHu-9eorE8"
+gigapipe.client_secret = "gigapipe_sk_6q9QLldhDmrWou4nlIFDWhULEMGBYJTI5lweMlXxC3A"
 
-gigapipe = gigapipe.GigapipeClient(client_id="gigapipe_pk_rHCX48J__V_AvZu0RzkhAw")
+gigapipe = gigapipe.GigapipeClient(client_id="gigapipe_pk_lEAYfmA2U6Aa04ckt5PnEw")
 
 
 ### /users/me (get)
@@ -12,6 +12,28 @@ gigapipe = gigapipe.GigapipeClient(client_id="gigapipe_pk_rHCX48J__V_AvZu0RzkhAw
 print('\n### User get info')
 print(gigapipe.users.get_info())
 
+# invite_object = {
+#     "email": "asdsa@asdasd.es",
+#     "organization_name": "gigapipe",
+# }
+#
+# response = gigapipe.invites.send_invite(invite_object)
+#
+# print('\n### Invites send')
+# print(response)
+
+
+t_object = {
+    'tax_type': 'au_abn',
+    'tax_value': '12345678912'
+}
+
+print('\n### Post tax id')
+print(gigapipe.stripe.post_tax_id(t_object))
+print(gigapipe.stripe.get_tax_id())
+print(gigapipe.stripe.delete_tax_id())
+print(gigapipe.stripe.get_tax_id())
+
 
 # gigapipe.clusters.expand_disk('cluster2', disk_id=9, payload={'size': 10.0})
 
